==> cl_appbase-0.0.13.tar.gz: test/placeholder_api/palceholder_test.dart <==
import 'package:cl_appbase/appbase.dart';
import 'package:flutter_test/flutter_test.dart';

import 'placeholder_api.dart';

void main() {
  test('Placeholder API: get posts', _resourceGetListTest);
  test('Placeholder API: get single post', _resourceGetElementTest);
  test('Placeholder API: get comments', _resourceGetNestedTest);
}

Future _resourceGetListTest() async {
  final api = PlaceholderApi();
  final posts = await api.posts.getList(0, -1);
  expect(posts.length, equals(100));
}

Future _resourceGetElementTest() async {
  final api = PlaceholderApi();
  final element = await api.posts.getElement(55);
  expect(element.id, equals(55));
  expect(element.title, isNotEmpty);
  expect(element.body, isNotEmpty);
}

Future _resourceGetNestedTest() async {
  final api = PlaceholderApi();
  final fail = () async => await api.comments.getList(0, -1);
  expect(fail, throwsA(isA<ApiException>()));
  final comments = await api.comments.getList(0, -1, {'postId': 4});
  expect(comments.length, equals(5));
}

/*
Future _getObjectTest() async {
  final api = PlaceholderApi();
  final singlePostResponse = await api.get(PlaceholderApi.postEndpoint, {'id': 1});
  singlePostResponse.throwOnError();
  print(singlePostResponse.data);
}

Future _getListTest() async {
  final api = PlaceholderApi();
  final postsResponse = await api.get(PlaceholderApi.postsEndpoint);
  postsResponse.throwOnError();
  print(postsResponse.data.length);
}

Future _postTest() async {
  final api = PlaceholderApi();
  final post = Post.create(title: 'moin', body: 'test');
  print('Sending:');
  print(post.toString());
  final postResponse = await api.post(PlaceholderApi.postsEndpoint, post);
  final responsePost = postResponse.data.first;
  print('Received:');
  print(responsePost.toString());
  expect(responsePost.title, equals(post.title));
  expect(responsePost.body, equals(post.body));
  expect(responsePost.userId, equals(post.userId));
}
*/

==> cl_appbase-0.0.46.tar.gz: test/placeholder_api/palceholder_test.dart <==
import 'package:cl_appbase/appbase.dart';
import 'package:flutter_test/flutter_test.dart';

import 'placeholder_api.dart';

void main() {
  test('Placeholder API: get posts', _resourceGetListTest);
  test('Placeholder API: get single post', _resourceGetElementTest);
  test('Placeholder API: get comments', _resourceGetNestedTest);
}

Future _resourceGetListTest() async {
  final api = PlaceholderApi();
  final posts = await api.posts.getList(0, -1);
  expect(posts.length, equals(100));
}

Future _resourceGetElementTest() async {
  final api = PlaceholderApi();
  final element = await api.posts.getElement(55);
  expect(element.id, equals(55));
  expect(element.title, isNotEmpty);
  expect(element.body, isNotEmpty);
}

Future _resourceGetNestedTest() async {
  final api = PlaceholderApi();
  final fail = () async => await api.comments.getList(0, -1);
  expect(fail, throwsA(isA<ApiException>()));
  final comments = await api.comments.getList(0, -1, params: {'postId': 4});
  expect(comments.length, equals(5));
}

/*
Future _getObjectTest() async {
  final api = PlaceholderApi();
  final singlePostResponse = await api.get(PlaceholderApi.postEndpoint, {'id': 1});
  singlePostResponse.throwOnError();
  print(singlePostResponse.data);
}

Future _getListTest() async {
  final api = PlaceholderApi();
  final postsResponse = await api.get(PlaceholderApi.postsEndpoint);
  postsResponse.throwOnError();
  print(postsResponse.data.length);
}

Future _postTest() async {
  final api = PlaceholderApi();
  final post = Post.create(title: 'moin', body: 'test');
  print('Sending:');
  print(post.toString());
  final postResponse = await api.post(PlaceholderApi.postsEndpoint, post);
  final responsePost = postResponse.data.first;
  print('Received:');
  print(responsePost.toString());
  expect(responsePost.title, equals(post.title));
  expect(responsePost.body, equals(post.body));
  expect(responsePost.userId, equals(post.userId));
}
*/
